@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10604 2017-12-05 06:15:05Z Lavender $
+# $Id: __init__.py 10719 2018-01-07 08:03:23Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2017-12-05 14:15:05 +0800 (週二, 05 十二月 2017) $
-# $Revision: 10604 $
+# $Date: 2018-01-07 16:03:23 +0800 (週日, 07 一月 2018) $
+# $Revision: 10719 $
 
 import os
 import warnings
@@ -77,6 +77,8 @@ def attachSettings(settingsDict):
     ADDING_INSTALLED_APPS = (
         'djangocms_history',
         'djangocms_forms',
+        'djangocms_file',
+        'djangocms_picture',
         'Zephyrus.boilerplate',
         'Zephyrus.landing',
         'Zephyrus.facebook',
