@@ -135,8 +135,8 @@ class Command(BaseCommand):
             staticDict = self.buildFileDict('static')
             staticDict['js/FixTemplate.js'] = \
                 hashlib.md5('js/FixTemplate.js').hexdigest()
-            staticDict['js/Workaround.js'] = \
-                hashlib.md5('js/Workaround.js').hexdigest()
+            staticDict['js/CMSContext.js'] = \
+                hashlib.md5('js/CMSContext.js').hexdigest()
             templateDict = self.buildFileDict('templates')
             fileDict = dict(staticDict)
             fileDict.update(templateDict)
@@ -339,9 +339,11 @@ class Command(BaseCommand):
             ele.text = ''
 
         if ele.tag == 'p':
-            commentStart = etree.Comment('cmsboilerplatetagstart=p')
+            commentStart = etree.Comment(
+                'FixCMS:cmsboilerplatetagstart=%s' % placeholderId)
             ele.addprevious(commentStart)
-            commentEnd = etree.Comment('cmsboilerplatetagend=p')
+            commentEnd = etree.Comment(
+                'FixCMS:cmsboilerplatetagend=%s' % placeholderId)
             ele.addnext(commentEnd)
 
         if ele.getchildren():
@@ -366,7 +368,7 @@ class Command(BaseCommand):
             ele.tail = "{% endplaceholder %}"
 
         if ele.tag in ADD_COMMENT_TO_PREVIOUS:
-            text = "CMS:%s" % placeholderId
+            text = "FixCMS:%s" % placeholderId
             comment = etree.Comment(text=text)
             ele.addprevious(comment)
 
@@ -485,6 +487,10 @@ class Command(BaseCommand):
         addJ.set('src', 'js/FixTemplate.js')
         addJ.tail = '\n'
 
+        addContext = etree.Element('script')
+        addContext.set('src', 'js/CMSContext.js')
+        addContext.tail = '\n'
+
         metaDescription = etree.Element('meta')
         metaDescription.set("name", "description")
         metaDescription.set(
@@ -498,6 +504,9 @@ class Command(BaseCommand):
         legel = etree.Comment(text=LEGEL)
         legel.tail = '\n'
 
+        staticPathJs = etree.Element('script')
+        staticPathJs.text = "var CMS_STATIC = \"{% static '' %}\";"
+
         # add cms data to head
         if createTitle:
             head.insert(0, title)
@@ -505,8 +514,10 @@ class Command(BaseCommand):
             head.insert(0, metaDescription)
         head.insert(0, comment) 
         head.insert(0, addJ)
+        head.insert(0, addContext)
         head.insert(0, workAroundComment)
         head.insert(0, jq)
+        head.insert(0, staticPathJs)
         head.insert(0, cmsData)  
         head.insert(0, pgAttr)
           
@@ -552,6 +563,7 @@ class Command(BaseCommand):
         html.addprevious(legel)
 
     def replaceKeyword(self, page, fileDict):
+        extraDict = {}
         for tag in page.iter():
             if tag.tag == 'script' or tag.tag == 'style':
                 if tag.text:  
@@ -567,6 +579,8 @@ class Command(BaseCommand):
                             tag.text = tag.text.replace(path, fileDict[path])
 
             for name, value in tag.items():
+                if value.startswith("//") or value.startswith("http"):
+                    continue
                 for path in fileDict:
                     value = value.replace('\\', '/')
                     # 考慮到有時 attr 的 value 可能不只 static 路徑，
@@ -584,6 +598,16 @@ class Command(BaseCommand):
                             continue
                         newValue = value.replace(path, fileDict[path])
                         tag.set(name, newValue)
+
+                # FIXME: 去掉副檔名
+                if name == 'data-vide-bg':
+                    for path in fileDict:
+                        if path.startswith(value):
+                            hashCode = hashlib.md5(value).hexdigest()
+                            extraDict[value] = hashCode
+                            tag.set(name, hashCode)
+        fileDict.update(extraDict)
+
                         
     def changeWordToMd5(self, page):
         for tag in page.iter():
