@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_templates.py 10591 2017-12-03 05:37:16Z Lavender $
+# $Id: build_templates.py 10649 2017-12-17 10:04:42Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-03 13:37:16 +0800 (週日, 03 十二月 2017) $
-# $Revision: 10591 $
+# $Date: 2017-12-17 18:04:42 +0800 (週日, 17 十二月 2017) $
+# $Revision: 10649 $
 
 import os
 import sys
@@ -25,6 +25,7 @@ from django.conf import settings
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, ROOT_DIR_PATH)
 from Zephyrus.boilerplate.management.commands import createLogger
+from Zephyrus.boilerplate.management.commands.BlackList import BLACK_LIST
 
 logger = createLogger(__name__, "BuildTemplates.log")
 
@@ -48,6 +49,9 @@ class Command(BaseCommand):
         hasError = 0
         
         for f in os.listdir(startPath):
+            if f in BLACK_LIST:
+                continue
+            
             tempPath = os.path.join(startPath, f)
             
             dbPath = settings.DATABASES['default']['NAME']
