@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 10626 2017-12-10 09:05:41Z Lavender $
+# $Id: pluginize.py 10720 2018-01-07 08:53:37Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-10 17:05:41 +0800 (週日, 10 十二月 2017) $
-# $Revision: 10626 $
+# $Date: 2018-01-07 16:53:37 +0800 (週日, 07 一月 2018) $
+# $Revision: 10720 $
 
 import os
 import json
@@ -21,6 +21,7 @@ import logging
 import shutil
 import hashlib
 import traceback
+import re
 
 from django.core.management.base import BaseCommand, CommandError
 from django.core.management import call_command
@@ -36,19 +37,56 @@ from cms.templatetags.cms_tags import *
 from filer.models.filemodels import File
 from cms.models.pagemodel import Page
 from lxml.html import fromstring
+from html5lib import sanitizer
+from html5lib.filters import sanitizer as filtersSanitizer
 
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH, FIXTURES_DIR_PATH, ROOT_DIR_PATH)
-from Zephyrus.boilerplate.management.commands import createLogger
+from Zephyrus.boilerplate.management.commands import (
+    createLogger, CSS_PROPERTIES)
 
 logger = createLogger(__name__, "Pluginize.log")
 
 jsPath = os.path.join(STATIC_DIR_PATH, 'js', 'FixTemplate.js')
+contextPath = os.path.join(STATIC_DIR_PATH, 'js', 'CMSContext.js')
 
 complexity = 0
 
 tagList = []
 
+# To fix #2985 
+sanitizer.HTMLSanitizerMixin.acceptable_css_properties = CSS_PROPERTIES
+sanitizer.HTMLSanitizerMixin.allowed_css_properties = CSS_PROPERTIES
+
+reString = ("^(#[0-9a-f]+|rgb\(\d+%?,\d*%?,?\d*%?\)?|\d{0,2}\.?\d{0,2}"
+            "(cm|em|ex|in|mm|pc|pt|px|%|,|\))?)$")
+
+def sanitize_css(self, style):
+        # 刪除了前兩個判斷，其他都一樣
+        if not re.match("^\s*([-\w]+\s*:[^:;]*(;\s*|$))*$", style):
+            return ''
+
+        clean = []
+        for prop, value in re.findall("([-\w]+)\s*:\s*([^:;]*)", style):
+            if not value:
+                continue
+            if prop.lower() in self.allowed_css_properties:
+                clean.append(prop + ': ' + value + ';')
+            elif prop.split('-')[0].lower() in ['background', 'border', 
+                                                'margin', 'padding']:
+                for keyword in value.split():
+                    if keyword not in self.acceptable_css_keywords and \
+                            not re.match(reString, keyword):
+                        break
+                else:
+                    clean.append(prop + ': ' + value + ';')
+            elif prop.lower() in self.allowed_svg_properties:
+                clean.append(prop + ': ' + value + ';')
+
+        return ' '.join(clean)
+
+sanitizer.HTMLSanitizerMixin.sanitize_css = sanitize_css
+
 class Attr(object):
     def __init__(self, name, value):
         self.name = name
@@ -249,10 +287,6 @@ class Command(BaseCommand):
                     line = json.dumps(data)
                     f.write(line)
 
-            """
-            with open(jsPath, 'w') as f:
-                f.write("$j( document ).ready(function() {\n")
-            """
             @transaction.atomic
             def process():
                 for file in os.listdir(path):
@@ -274,12 +308,7 @@ class Command(BaseCommand):
                     f.close()
 
             process()
-            """
-            divClass = 'div' + hashlib.md5(' __tmp__img__div').hexdigest()
-            with open(jsPath, 'a+') as f:
-                f.write("$j('.%s').remove();\n" % divClass)
-                f.write("});")
-            """
+            
             # Unique List obj
             newTagList = []
             for tag in tagList:
@@ -289,13 +318,20 @@ class Command(BaseCommand):
                         notAdd = True
                 if not notAdd:
                     newTagList.append(tag)
+
+            # build FixTemplate.js
             temp = get_template('boilerplate/js/FixTemplate.js')
+            content = temp.render()
+            with open(jsPath, 'w') as f:
+                f.write(content)
+
+            # build CMSContext.js
+            temp = get_template('boilerplate/js/CMSContext.js')
             replaceStr = Context({
                 'tagList': newTagList, 
             })
-            
             content = temp.render(replaceStr)
-            with open(jsPath, 'w') as f:
+            with open(contextPath, 'w') as f:
                 f.write(content)
 
             if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
